'use strict';

const path = require('path');
const fs = require('fs');
const getPublicUrlOrPath = require('react-dev-utils/getPublicUrlOrPath');
const appDirectory = fs.realpathSync(process.cwd());
const resolveApp = relativePath => path.resolve(appDirectory, relativePath);

const publicUrlOrPath = getPublicUrlOrPath(
  process.env.NODE_ENV === 'development',
  require(resolveApp('package.json')).homepage,
  process.env.PUBLIC_URL
);

const moduleFileExtensions = [
  'web.mjs',
  'mjs',
  'web.js',
  'js',
  'web.ts',
  'ts',
  'web.tsx',
  'tsx',
  'json',
  'web.jsx',
  'jsx',
];

const resolveModule = (resolveFn, filePath) => {
  const extension = moduleFileExtensions.find(extension =>
    fs.existsSync(resolveFn(`${filePath}.${extension}`))
  );
  if (extension) {
    return resolveFn(`${filePath}.${extension}`);
  }
  return resolveFn(`${filePath}.js`);
};

module.exports = {
  dotenv: resolveApp('.env'),
  appPath: resolveApp('.'),
  appBuild: resolveApp('build'),
  appPublic: resolveApp('public'),
  appHtml: resolveApp('public/index.html'),
  appIndexJs: resolveModule(resolveApp, 'src/index'),
  appPackageJson: resolveApp('package.json'),
  appSrc: resolveApp('src'),
  appStatic: resolveApp('static'),
  appTsConfig: resolveApp('tsconfig.json'),
  useTypeScript: fs.existsSync(resolveApp('tsconfig.json')),
  appJsConfig: resolveApp('jsconfig.json'),
  yarnLockFile: resolveApp('yarn.lock'),
  useYarn: fs.existsSync(resolveApp('yarn.lock')),
  testsSetup: resolveModule(resolveApp, 'src/setupTests'),
  proxySetup: resolveApp('src/setupProxy.js'),
  appNodeModules: resolveApp('node_modules'),
  swSrc: resolveModule(resolveApp, 'src/service-worker'),
  mjdConfigPath: resolveApp('mjd-config.js'),
  publicUrlOrPath,
};

// 支持自动补全的文件后缀
module.exports.moduleFileExtensions = moduleFileExtensions;
// 缓存文件的存放地址
module.exports.cachePaths = {
  eslint: path.resolve(appDirectory, 'node_modules/.cache/.eslintcache'),
  webpack: path.resolve(appDirectory, 'node_modules/.cache/webpack'),
  buildConfig: path.resolve(appDirectory, 'node_modules/.cache/.buildConfigCache.json'),
}
