

const paths = require('../paths');
const PnpWebpackPlugin = require("pnp-webpack-plugin");

// Source maps are resource heavy and can cause out of memory issue for large source files.
const shouldUseSourceMap = process.env.GENERATE_SOURCEMAP !== "false";

module.exports = (webpackEnv) => {
  const isEnvDevelopment = webpackEnv === "development";
  const isEnvProduction = webpackEnv === "production";
  // Variable used for enabling profiling in Production
  // passed into alias object. Uses a flag if passed into the build command
  const isEnvProductionProfile = isEnvProduction && process.argv.includes("--profile");
  return {
    mode: isEnvProduction ? "production" : isEnvDevelopment && "development",
    // Stop compilation early in production
    bail: isEnvProduction,
    devtool: isEnvProduction  ? shouldUseSourceMap  ? "source-map" : false : isEnvDevelopment && "cheap-module-source-map",
    watchOptions: { ignored: ['**/.git/**', '**/node_modules/**', '**/dist/**'] },
    entry: isEnvDevelopment ? [paths.appIndexJs] : paths.appIndexJs,
    output: require("./output.config")(isEnvDevelopment,isEnvProduction),
    optimization: require("./optimization.config")(isEnvProduction, isEnvProductionProfile),
    resolve: require("./resolve.config")(isEnvProductionProfile),
    resolveLoader: {
      plugins: [
        // Also related to Plug'n'Play, but this time it tells webpack to load its loaders
        // from the current package.
        PnpWebpackPlugin.moduleLoader(module),
      ],
    },
    module: require("./module.config")(isEnvDevelopment, isEnvProduction, shouldUseSourceMap),
    plugins: require("./plugin.config")(isEnvDevelopment, isEnvProduction),
    performance: false,
  }
}